@@ -12,6 +12,12 @@ pub enum PgFunction {
     WebsearchToTsquery,
     TsRank,
     TsRankCd,
+    #[cfg(feature = "postgres-array")]
+    Any,
+    #[cfg(feature = "postgres-array")]
+    Some,
+    #[cfg(feature = "postgres-array")]
+    All,
 }
 
 /// Function call helper.
@@ -229,4 +235,76 @@ impl PgFunc {
     {
         Expr::func(Function::PgFunction(PgFunction::TsRankCd)).args(vec![vector, query])
     }
+
+    /// Call `ANY` function. Postgres only.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use sea_query::{tests_cfg::*, *};
+    ///
+    /// let query = Query::select()
+    ///     .expr(PgFunc::any(Expr::val(vec![0, 1])))
+    ///     .to_owned();
+    ///
+    /// assert_eq!(
+    ///     query.to_string(PostgresQueryBuilder),
+    ///     r#"SELECT ANY('{0,1}')"#
+    /// );
+    /// ```
+    #[cfg(feature = "postgres-array")]
+    pub fn any<T>(expr: T) -> SimpleExpr
+    where
+        T: Into<SimpleExpr>,
+    {
+        Expr::func(Function::PgFunction(PgFunction::Any)).arg(expr)
+    }
+
+    /// Call `SOME` function. Postgres only.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use sea_query::{tests_cfg::*, *};
+    ///
+    /// let query = Query::select()
+    ///     .expr(PgFunc::some(Expr::val(vec![0, 1])))
+    ///     .to_owned();
+    ///
+    /// assert_eq!(
+    ///     query.to_string(PostgresQueryBuilder),
+    ///     r#"SELECT SOME('{0,1}')"#
+    /// );
+    /// ```
+    #[cfg(feature = "postgres-array")]
+    pub fn some<T>(expr: T) -> SimpleExpr
+    where
+        T: Into<SimpleExpr>,
+    {
+        Expr::func(Function::PgFunction(PgFunction::Some)).arg(expr)
+    }
+
+    /// Call `ALL` function. Postgres only.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use sea_query::{tests_cfg::*, *};
+    ///
+    /// let query = Query::select()
+    ///     .expr(PgFunc::all(Expr::val(vec![0, 1])))
+    ///     .to_owned();
+    ///
+    /// assert_eq!(
+    ///     query.to_string(PostgresQueryBuilder),
+    ///     r#"SELECT ALL('{0,1}')"#
+    /// );
+    /// ```
+    #[cfg(feature = "postgres-array")]
+    pub fn all<T>(expr: T) -> SimpleExpr
+    where
+        T: Into<SimpleExpr>,
+    {
+        Expr::func(Function::PgFunction(PgFunction::All)).arg(expr)
+    }
 }
