@@ -1056,6 +1056,29 @@ fn insert_5() {
     );
 }
 
+#[test]
+fn insert_6() {
+    assert_eq!(
+        Query::insert()
+            .into_table(Glyph::Table)
+            .or_default_values()
+            .to_string(MysqlQueryBuilder),
+        "INSERT INTO `glyph` VALUES ()"
+    );
+}
+
+#[test]
+fn insert_7() {
+    assert_eq!(
+        Query::insert()
+            .into_table(Glyph::Table)
+            .or_default_values()
+            .returning_col(Glyph::Id)
+            .to_string(MysqlQueryBuilder),
+        "INSERT INTO `glyph` VALUES ()"
+    );
+}
+
 #[test]
 fn insert_from_select() {
     assert_eq!(
