@@ -232,6 +232,26 @@ fn create_10() {
     );
 }
 
+#[test]
+fn create_11() {
+    assert_eq!(
+        Table::create()
+            .table(Char::Table)
+            .col(
+                ColumnDef::new(Char::CreatedAt)
+                    .timestamp_with_time_zone_len(0)
+                    .not_null()
+            )
+            .to_string(PostgresQueryBuilder),
+        vec![
+            r#"CREATE TABLE "character" ("#,
+            r#""created_at" timestamp(0) with time zone NOT NULL"#,
+            r#")"#,
+        ]
+        .join(" ")
+    );
+}
+
 #[test]
 fn drop_1() {
     assert_eq!(
@@ -327,3 +347,15 @@ fn alter_5() {
 fn alter_6() {
     Table::alter().to_string(PostgresQueryBuilder);
 }
+
+#[test]
+fn alter_7() {
+    assert_eq!(
+        Table::alter()
+            .table(Font::Table)
+            .add_column(ColumnDef::new(Alias::new("new_col")).integer())
+            .rename_column(Font::Name, Alias::new("name_new"))
+            .to_string(PostgresQueryBuilder),
+        r#"ALTER TABLE "font" ADD COLUMN "new_col" integer, RENAME COLUMN "name" TO "name_new""#
+    );
+}
